==> heroes-0.0.1.tar.gz: lib/src/app_clock_service/app_clock.dart <==
import '../configuration/configuration_service.dart';
import '../configuration/data_classes/configuration.dart';
import '../log/log.dart';
import 'dart:async';
import 'dart:isolate';

Isolate _timerIsolate;
ReceivePort mainToIsolate;

void runTimer(SendPort sendPort) {
  int counter = 0;
  Timer.periodic(new Duration(minutes: AppClock.rebootFrequency.inMinutes), (Timer t) {
    counter++;
    String msg = 'notification ' + counter.toString();  
    print('HEROES_FLUTTER_PLUGIN :: SEND: ' + msg + ' - ');
    sendPort.send(msg);
  });
}

class AppClock {
  factory AppClock() => _instance;

  AppClock._internal()
  {
    ConfigurationService configurationService = ConfigurationService();
    if (configurationService.isLoaded) {
      _rebootFrequency = configurationService.configuration.rebootFrequency;
    }
    configurationService.addOnConfigurationChangedCallback(_onConfigurationChangedCallback);
  }

  static Duration get rebootFrequency => _rebootFrequency;
  static Duration _rebootFrequency = Duration(minutes: 1);

  static final _instance = AppClock._internal();

  ReceivePort isolateToMain;

  Completer completer = new Completer<SendPort>();
  
  void startIsolate(Function callback) async {
  ReceivePort receivePort= ReceivePort(); //port for this main isolate to receive messages.
  _timerIsolate = await Isolate.spawn(runTimer, receivePort.sendPort);
  receivePort.listen((data) async {
    await callback();
    print('HEROES_FLUTTER_PLUGIN :: RECEIVE: ' + data + ', ');
    Log.addToLog("RECEIVE: " + data + ", ");
  });
}

  void stopIsolate() {
    if (_timerIsolate != null) {
      print('HEROES_FLUTTER_PLUGIN :: killing _timerIsolate');
      Log.addToLog("killing _timerIsolate");
      _timerIsolate.kill(priority: Isolate.immediate);
      _timerIsolate = null;
    }
  }

  void _onConfigurationChangedCallback(Configuration newConfiguration)
  {
    final newRebootFrequency = newConfiguration.rebootFrequency;
    if (_rebootFrequency != newRebootFrequency)
    {
      Log.addToLog("rebootFrequency changed: " +
          _rebootFrequency.inMinutes.toString() + " minutes -> " +
          newRebootFrequency.inMinutes.toString() + " minutes.");
      _rebootFrequency = newRebootFrequency;
    }
  }
}

==> heroes-0.1.0.tar.gz: lib/src/app_clock_service/app_clock.dart <==
import '../configuration/configuration_service.dart';
import '../configuration/data_classes/configuration.dart';
import '../log/log.dart';
import 'dart:async';
import 'dart:isolate';

Isolate _timerIsolate;
ReceivePort mainToIsolate;

void runTimer(SendPort sendPort) {
  int counter = 0;
  Timer.periodic(new Duration(minutes: AppClock.rebootFrequency.inMinutes),
      (Timer t) {
    counter++;
    String msg = 'notification ' + counter.toString();
    print('HEROES_FLUTTER_PLUGIN :: SEND: ' + msg + ' - ');
    sendPort.send(msg);
  });
}

class AppClock {
  factory AppClock() => _instance;

  AppClock._internal() {
    ConfigurationService configurationService = ConfigurationService();
    if (configurationService.isLoaded) {
      _rebootFrequency = configurationService.configuration.rebootFrequency;
    }
    configurationService
        .addOnConfigurationChangedCallback(_onConfigurationChangedCallback);
  }

  static Duration get rebootFrequency => _rebootFrequency;
  static Duration _rebootFrequency = Duration(minutes: 1);

  static final _instance = AppClock._internal();

  ReceivePort isolateToMain;

  Completer completer = new Completer<SendPort>();

  void startIsolate(Function callback) async {
    ReceivePort receivePort =
        ReceivePort(); //port for this main isolate to receive messages.
    _timerIsolate = await Isolate.spawn(runTimer, receivePort.sendPort);
    receivePort.listen((data) async {
      await callback();
      print('HEROES_FLUTTER_PLUGIN :: RECEIVE: ' + data + ', ');
      Log.addToLog("RECEIVE: " + data + ", ");
    });
  }

  void stopIsolate() {
    if (_timerIsolate != null) {
      print('HEROES_FLUTTER_PLUGIN :: killing _timerIsolate');
      Log.addToLog("killing _timerIsolate");
      _timerIsolate.kill(priority: Isolate.immediate);
      _timerIsolate = null;
    }
  }

  void _onConfigurationChangedCallback(Configuration newConfiguration) {
    final newRebootFrequency = newConfiguration.rebootFrequency;
    if (_rebootFrequency != newRebootFrequency) {
      Log.addToLog("rebootFrequency changed: " +
          _rebootFrequency.inMinutes.toString() +
          " minutes -> " +
          newRebootFrequency.inMinutes.toString() +
          " minutes.");
      _rebootFrequency = newRebootFrequency;
    }
  }
}
